@@ -229,8 +229,7 @@ void SaveThread::run(void)
 		
 	while(fr)
 	{
-		fgets(buf, sizeof(buf), fr);
-		if(feof(fr))
+		if(!fgets(buf, sizeof(buf), fr) || feof(fr))
 			break;
 			
 		cp = buf;
@@ -358,8 +357,7 @@ void LoadThread::run(void)
 load:
 	for(;;)
 	{
-		fgets(path, sizeof(path), fp);
-		if(feof(fp))
+		if(!fgets(path, sizeof(path), fp) || feof(fp))
 			break;
 
 		cp = path;
