@@ -43,7 +43,7 @@ using namespace ost;
 
 bool SQLMethods::scrSQL(void)
 {
-	SQLDatabase *current;
+	SQLDatabase *current = NULL;
 	const char *kw = getKeyoption("results"), *name;
 	Symbol *sym = NULL;
 	char dbname[128];
