@@ -192,6 +192,14 @@ const char *ScriptCommand::check(char *keyword, Line *line, ScriptImage *img)
         return "unknown command";
 }
 
+void ScriptCommand::aliasModule(const char *id, const char *use)
+{
+	char temp[65];
+
+	snprintf(temp, sizeof(temp), "use.%s", id);
+	setValue(temp, use);
+}
+
 unsigned long ScriptCommand::getTrapDefault(void)
 {
 	return 0x03;
