@@ -55,6 +55,18 @@ ScriptObject::~ScriptObject()
 ScriptImage::ScriptImage(ScriptCommand *cmd, const char *symset) :
 Keydata(symset), Assoc()
 {
+        static Script::Initial initial[] = {
+                {"script.index", 6 * SCRIPT_STACK_SIZE, ""},
+                {"script.stack", 3, "-"},
+                {"script.error", 64, "none"},
+                {"script.home", 64, "none"},
+                {"script.token", 1, ","},
+                {"script.decimal", 1, "."},
+		{"script.authorize", 23, ""},
+                {NULL, 0, NULL}
+        };
+
+
         cmds = cmd;
         memset(index, 0, sizeof(index));
         refcount = 0;
@@ -63,6 +75,8 @@ Keydata(symset), Assoc()
 	select = selecting = registration = NULL;
 	memset(advertising, 0, sizeof(advertising));
 	instance = ++serial;
+
+	load(initial);
 }
 
 ScriptImage::~ScriptImage()
@@ -170,7 +184,7 @@ unsigned ScriptImage::gather(const char *suffix, Name **array, unsigned max)
 	unsigned sort = 0;
 	unsigned key = 0;
 	Name *scr;
-	char *ext;
+	const char *ext;
 	int ins;
 
 	while(count < max && key < SCRIPT_INDEX_SIZE)
