@@ -49,6 +49,9 @@ ScriptProperty::ScriptProperty(const char *name)
 	first = this;
 }
 
+ScriptProperty::~ScriptProperty()
+{}
+
 long ScriptProperty::getValue(const char *data)
 {
 	return (long)strlen(data);
