@@ -668,6 +668,7 @@ protected:
 public:
 	ScriptBinder(const char *id = NULL);
 	ScriptBinder(Script::Define *extensions);
+	virtual ~ScriptBinder();
 
 	static const char *check(Line *line, ScriptImage *img);
 	static void shutdown(void);
@@ -1756,6 +1757,7 @@ public:
         virtual long getValue(const char *data);
 
 	ScriptProperty(const char *name);
+	virtual ~ScriptProperty();
 
 	static ScriptProperty *find(const char *name);
 };
